<?php

namespace Drupal\Tests\config_overlay\Functional;

use Drupal\Core\Config\StorageInterface;

/**
 * Tests installation of the Umami profile with Config Overlay.
 *
 * @group config_overlay
 */
class ConfigOverlayDemoUmamiTest extends ConfigOverlayFullProfileTestBase {

  /**
   * {@inheritdoc}
   */
  protected $profile = 'demo_umami';

  /**
   * {@inheritdoc}
   */
  protected function prepareEnvironment() {
    parent::prepareEnvironment();

    /* @see https://www.drupal.org/project/drupal/issues/2990234 */
    $this->translationFilesDirectory = $this->publicFilesDirectory . '/translations';
    mkdir($this->translationFilesDirectory, 0777, TRUE);

    // Prepare a translation file to avoid attempting to download a translation
    // file from the actual translation server during the test.
    file_put_contents("$this->root/$this->translationFilesDirectory/drupal-8.0.0.es.po", '');
  }

  /**
   * {@inheritdoc}
   */
  protected function getExpectedConfig(): array {
    $expected_config = parent::getExpectedConfig();

    unset($expected_config[StorageInterface::DEFAULT_COLLECTION]['filter.format.restricted_html']['roles']);

    return $expected_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getOverriddenConfig(): array {
    $overridden_config = parent::getOverriddenConfig();

    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['core.extension']['theme'] = [
      'claro' => 0,
      'umami' => 0,
    ];

    // Add text formats with a roles property.
    /* @see https://www.drupal.org/project/drupal/issues/3167198 */
    /* @see \Drupal\Tests\config_overlay\Functional\ConfigOverlayDemoUmamiTest::getExpectedConfig() */
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['filter.format.restricted_html'] = [];

    return $overridden_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getModules(): array {
    $modules = parent::getModules();
    $modules += [
      'config_translation' => 0,
      'content_moderation' => 0,
      'demo_umami_content' => 0,
      'language' => 0,
      'layout_builder' => 0,
      'layout_discovery' => 0,
      'locale' => 0,
      'media' => 0,
      'media_library' => 0,
      'responsive_image' => 0,
      'workflows' => 0,
      'content_translation' => 10,
    ];
    // See https://www.drupal.org/node/3355112
    // See https://www.drupal.org/node/3410260
    if (version_compare(\Drupal::VERSION, '10.1.0-dev', '>=') && version_compare(\Drupal::VERSION, '10.3.0', '<')) {
      $modules['sdc'] = 0;
      $modules['serialization'] = 0;
    }
    return $modules;
  }

}
