<?php

namespace Drupal\Tests\config_overlay\Functional;

use Drupal\Core\Config\StorageInterface;

/**
 * Provides a base class for "full" profiles with Config Overlay.
 *
 * "Full" in this context means profiles that actually provide a fully
 * configured environment such as Standard or Umami and unlike Minimal or
 * Testing.
 */
abstract class ConfigOverlayFullProfileTestBase extends ConfigOverlayProfileTestBase {

  /**
   * {@inheritdoc}
   */
  protected function getOverriddenConfig(): array {
    $overridden_config = parent::getOverriddenConfig();

    // The system site configuration is overridden by the test, so make it match
    // the values given in Standard's or Umami's version of the file.
    /* @see \Drupal\Tests\config_overlay\Functional\ConfigOverlayTestingTest::getOverriddenConfig() */
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['system.site']['page']['front'] = '/node';

    /* @see standard_form_install_configure_submit() */
    /* @see demo_umami_form_install_configure_submit() */
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['contact.form.feedback'] = [
      'recipients' => ['simpletest@example.com'],
    ];

    return $overridden_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getModules(): array {
    $modules = parent::getModules();

    $modules += [
      'announcements_feed' => 0,
      'automated_cron' => 0,
      'big_pipe' => 0,
      'block' => 0,
      'block_content' => 0,
      'breakpoint' => 0,
      'ckeditor5' => 0,
      'config' => 0,
      'contact' => 0,
      'contextual' => 0,
      'datetime' => 0,
      'dblog' => 0,
      'dynamic_page_cache' => 0,
      'editor' => 0,
      'field' => 0,
      'field_ui' => 0,
      'file' => 0,
      'filter' => 0,
      'help' => 0,
      'history' => 0,
      'image' => 0,
      'link' => 0,
      'menu_link_content' => 0,
      'menu_ui' => 0,
      'node' => 0,
      'options' => 0,
      'page_cache' => 0,
      'path' => 0,
      'search' => 0,
      'shortcut' => 0,
      'taxonomy' => 0,
      'text' => 0,
      'toolbar' => 0,
      'views_ui' => 0,
      'views' => 10,
    ];

    /* @see https://www.drupal.org/node/3376405 */
    /* @see https://www.drupal.org/node/3377475 */
    /* @see https://www.drupal.org/node/3399817 */
    if (version_compare(\Drupal::VERSION, '10.2.0-dev', '<')) {
      $modules['tour'] = 0;
      unset($modules['announcements_feed']);
    }

    return $modules;
  }

}
