<?php

namespace Drupal\Tests\config_overlay\Functional;

use Drupal\Core\Config\StorageInterface;

/**
 * Tests installation of the Standard profile with Config Overlay.
 *
 * @group config_overlay
 */
class ConfigOverlayStandardTest extends ConfigOverlayFullProfileTestBase {

  /**
   * {@inheritdoc}
   */
  protected $profile = 'standard';

  /**
   * {@inheritdoc}
   */
  protected function getExpectedConfig(): array {
    $expected_config = parent::getExpectedConfig();

    foreach (['basic_html', 'full_html', 'restricted_html'] as $format_id) {
      unset($expected_config[StorageInterface::DEFAULT_COLLECTION]["filter.format.$format_id"]['roles']);
    }

    return $expected_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getOverriddenConfig(): array {
    $overridden_config = parent::getOverriddenConfig();

    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['core.extension']['theme'] = [
      'olivero' => 0,
      'claro' => 0,
    ];

    // The Claro theme settings are incorrectly not part of the shipped
    // configuration.
    // @todo Open an issue for this.
    $overridden_config[StorageInterface::DEFAULT_COLLECTION]['claro.settings'] = [
      'third_party_settings' => [
        'shortcut' => [
          'module_link' => TRUE,
        ],
      ],
    ];

    // Add text formats.
    /* @see https://www.drupal.org/project/drupal/issues/3167198 */
    /* @see \Drupal\Tests\config_overlay\Functional\ConfigOverlayStandardTest::getExpectedConfig() */
    foreach (['basic_html', 'full_html', 'restricted_html'] as $format_id) {
      $overridden_config[StorageInterface::DEFAULT_COLLECTION]["filter.format.$format_id"] = [];
    }

    return $overridden_config;
  }

  /**
   * {@inheritdoc}
   */
  protected function getModules(): array {
    return parent::getModules() + [
      'comment' => 0,
    ];
  }

}
